summaryrefslogtreecommitdiffstats
path: root/vtysh
diff options
context:
space:
mode:
authorQuentin Young <qlyoung@cumulusnetworks.com>2017-02-01 23:01:17 +0100
committerQuentin Young <qlyoung@cumulusnetworks.com>2017-02-03 19:48:04 +0100
commita0b4b67e80d41f013267b86dad632b5f6114f7e8 (patch)
tree8e08fb25ecc2eaac67e32547883078558d28221f /vtysh
parentMerge pull request #158 from LabNConsulting/working/2.0/patch-set/rfapi+vty (diff)
downloadfrr-a0b4b67e80d41f013267b86dad632b5f6114f7e8.tar.xz
frr-a0b4b67e80d41f013267b86dad632b5f6114f7e8.zip
vtysh: Quagga.conf -> Frr.conf
Signed-off-by: Quentin Young <qlyoung@cumulusnetworks.com>
Diffstat (limited to 'vtysh')
-rw-r--r--vtysh/vtysh.h2
-rw-r--r--vtysh/vtysh_main.c8
2 files changed, 5 insertions, 5 deletions
diff --git a/vtysh/vtysh.h b/vtysh/vtysh.h
index 537f944a7..39bf64f30 100644
--- a/vtysh/vtysh.h
+++ b/vtysh/vtysh.h
@@ -49,7 +49,7 @@ DECLARE_MGROUP(MVTYSH)
/* vtysh local configuration file. */
#define VTYSH_DEFAULT_CONFIG "vtysh.conf"
-#define QUAGGA_DEFAULT_CONFIG "Quagga.conf"
+#define FRR_DEFAULT_CONFIG "Frr.conf"
enum vtysh_write_integrated {
WRITE_INTEGRATED_UNSPECIFIED,
diff --git a/vtysh/vtysh_main.c b/vtysh/vtysh_main.c
index 78b17be05..127cb70ad 100644
--- a/vtysh/vtysh_main.c
+++ b/vtysh/vtysh_main.c
@@ -46,7 +46,7 @@ char *progname;
/* Configuration file name and directory. */
static char vtysh_config_always[MAXPATHLEN] = SYSCONFDIR VTYSH_DEFAULT_CONFIG;
-static char quagga_config_default[MAXPATHLEN] = SYSCONFDIR QUAGGA_DEFAULT_CONFIG;
+static char quagga_config_default[MAXPATHLEN] = SYSCONFDIR FRR_DEFAULT_CONFIG;
char *quagga_config = quagga_config_default;
char history_file[MAXPATHLEN];
@@ -357,17 +357,17 @@ main (int argc, char **argv, char **env)
/*
* Overwrite location for Quagga.conf
*/
- vtysh_configfile_name = strrchr(QUAGGA_DEFAULT_CONFIG, '/');
+ vtysh_configfile_name = strrchr(FRR_DEFAULT_CONFIG, '/');
if (vtysh_configfile_name)
/* skip '/' */
vtysh_configfile_name++;
else
/*
* QUAGGA_DEFAULT_CONFIG configured with relative path
* during config? Should really never happen for
* sensible config
*/
- vtysh_configfile_name = (char *) QUAGGA_DEFAULT_CONFIG;
+ vtysh_configfile_name = (char *) FRR_DEFAULT_CONFIG;
strlcpy(quagga_config_default, optarg, sizeof(vtysh_config_always));
strlcat(quagga_config_default, "/", sizeof(vtysh_config_always));
strlcat(quagga_config_default, vtysh_configfile_name,
@@ -357,17 +357,17 @@ main (int argc, char **argv, char **env)
else
/*
- * QUAGGA_DEFAULT_CONFIG configured with relative path
+ * FRR_DEFAULT_CONFIG configured with relative path
* during config? Should really never happen for
* sensible config